@@ -9,14 +9,39 @@ spectralResampling <- function (
 no_data <- -9999.999  
 if (x@spectra@fromRaster)
   return(.blockwise(speclib_obj =  "x", pos = 1))
-  
-if (is.na(response_function))
+
+if (!is.speclib(response_function))
 {
-  spectral_response_function <- FALSE
-  response_function <- FALSE
+  if (is.na(response_function))
+  {
+    spectral_response_function <- FALSE
+    response_function <- FALSE
+  } else {  
+    spectral_response_function <- TRUE
+  }
 } else {
+  response_function <- .transform_irr_response(response_function)
+  if (missing(sensor))
+  {
+    sensor <- apply(spectra(response_function), 1,
+                    function(x, wv)
+    {
+      maxval <- max(x, na.rm = TRUE)
+      maxpos <- which.min(abs(x-maxval))
+      x_l <- x[1:maxpos]
+      x_r <- x[c((maxpos+1):length(x))]
+      fwhm_l <- which.min(abs(x_l - maxval/2))
+      fwhm_r <- maxpos + which.min(abs(x_r - maxval/2))
+      fwhm <- wv[c(fwhm_l, fwhm_r)]
+      center <- wv[floor(fwhm_l + (fwhm_r- fwhm_l)/2)]
+      fwhm <- fwhm[2] - fwhm[1]
+      return(c(center, fwhm))
+    }, wavelength(response_function))
+    sensor <- data.frame(fwhm = sensor[2,], center = sensor[1,])
+  } 
   spectral_response_function <- TRUE
 }
+
 if (continuousdata!="auto")
 {
   if (mode(continuousdata)!="logical")
@@ -45,7 +70,7 @@ if (is.data.frame(sensor))
   if (continuousdata=="auto") 
     continuousdata <- FALSE
 } else {
-  if (!any(get.sensor.name(sensor)==c("Hyperion", "EnMAP")))
+  if (!any(.get.sensor.name(sensor)==c("Hyperion", "EnMAP")))
   {
     if (continuousdata=="auto") 
       continuousdata <- FALSE      
@@ -53,19 +78,19 @@ if (is.data.frame(sensor))
     if (continuousdata=="auto") 
       continuousdata <- TRUE
   }
-  if (response_function)
-  {
-    if (attr(result,"wlunit")!=attr(response,"wlunit"))
-      stop(paste("Wavelength must be in [",attr(response,"wlunits"),"]",sep=""))
-  }
+#   if (response_function)
+#   {
+#     if (attr(result,"wlunit")!=attr(response,"wlunit"))
+#       stop(paste("Wavelength must be in [",attr(response,"wlunits"),"]",sep=""))
+#   }
 }
 spectra <- matrix(data=0,nrow=nrow(x),ncol=nch)
 rm_vec <- vector(mode="numeric")
 if (spectral_response_function)
 {
   responsedim <- c(as.double(attr(response, "minwl")),
-                    as.double(attr(response, "maxwl")),
-                    as.double(attr(response, "stepsize")))
+                   as.double(attr(response, "maxwl")),
+                   as.double(attr(response, "stepsize")))
   cha_names <- idSpeclib(response)
 
   x <- as.matrix(x)
@@ -119,7 +144,7 @@ if (is.data.frame(sensor))
 {
   sensor <- "user defined"
 } else {
-  if (is.numeric(sensor)) sensor <- get.sensor.name(sensor)
+  if (is.numeric(sensor)) sensor <- .get.sensor.name(sensor)
 }
 usagehistory(result) <- paste("Integrated spectra to",sensor,"channels")
 
